﻿using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Security.Cryptography.X509Certificates;

namespace SubscriberServicesClient.Helpers
{
	[ExcludeFromCodeCoverage]
	public class CertificateRepository
	{
		public static X509Store CertificateStore
		{
			get
			{
				return new X509Store(StoreName.My, StoreLocation.CurrentUser);
			}
		}

		public static List<string> GetPersonalCertificatesFromSystem()
		{
			var store = CertificateStore;
			try
			{
				var result = new List<string>();
				store.Open(OpenFlags.ReadOnly);
				foreach (var certificate in store.Certificates)
				{
					if (certificate.Subject.Contains("CN=") && certificate.HasPrivateKey)
					{
						result.Add(certificate.Subject.Substring(3));
					}
				}
				return result;
			}
			finally
			{
				store.Close();
			}
		}

		public static X509Certificate2 GetSelectedCertificate(object subjectName)
		{
			var store = CertificateStore;
			try
			{
				store.Open(OpenFlags.ReadOnly);
				foreach (var certificate in store.Certificates)
				{
					if (certificate.Subject.Substring(3).Equals(subjectName))
					{
						return certificate;
					}
				}
				return null;
			}
			finally
			{
				store.Close();
			}
		}
	}
}