﻿using System;
using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Windows.Forms;
using SubscriberServicesClient.Helpers;

namespace SubscriberServicesClient
{
	public partial class LoginDialog : Form
	{
		private readonly ISubscriberServiceForm _form;
		public Func<List<string>> GetPersonalCertificates = CertificateRepository.GetPersonalCertificatesFromSystem;

		[ExcludeFromCodeCoverage]
		public LoginDialog() : this(null)
		{
		}

		public LoginDialog(ISubscriberServiceForm form)
		{
			InitializeComponent();
			_form = form;
		}

		public void LoginDialog_Load(object sender, EventArgs e)
		{
			InitializeCertificates();
			if (_form.ShouldUseGatewayCredentials)
			{
				UsePassword.Checked = true;
				UserName.Text = _form.CurrentUserName;
				Password.Text = _form.CurrentPassword;
			}
			else
			{
				UseCertificate.Checked = true;
				Certificates.SelectedItem = _form.SelectedCertificateName;
			}
		}
		public ComboBox Certificates
		{
			get
			{
				return ddlCertificates;
			}
		}

		private void InitializeCertificates()
		{
			ddlCertificates.Items.Clear();
			ddlCertificates.Items.AddRange(GetPersonalCertificates().ToArray());
			if (ddlCertificates.Items.Count > 0)
			{
				ddlCertificates.SelectedIndex = 0;
			}
		}

		public void AcceptCredentials(object sender, EventArgs e)
		{
			_form.ShouldUseGatewayCredentials = UsePassword.Checked;
			if (_form.ShouldUseGatewayCredentials)
			{
				_form.CurrentEndpointName = "subscriber";
				_form.CurrentUserName = UserName.Text;
				_form.CurrentPassword = Password.Text;
			}
			else
			{
				_form.CurrentEndpointName = "regulator";
				_form.SelectedCertificateName = (string)Certificates.SelectedItem;
			}
			Close();
		}

		public RadioButton UseCertificate
		{
			get
			{
				return rbUseCertificate;
			}
		}

		public RadioButton UsePassword
		{
			get
			{
				return rbUsePassword;
			}
		}

		public void LoginMethodChanged(object sender, EventArgs e)
		{
			Certificates.Enabled = UseCertificate.Checked;
			UserName.Enabled = UsePassword.Checked;
			Password.Enabled = UsePassword.Checked;
		}

		public TextBox UserName
		{
			get
			{
				return txtUserName;
			}
		}

		public TextBox Password
		{
			get
			{
				return txtPassword;
			}
		}

		[ExcludeFromCodeCoverage]
		private void CancelDialog(object sender, EventArgs e)
		{
			Close();
		}
	}
}
